@@ -6,6 +6,8 @@
 */
 
 #include "printstyle.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "printingwizard.h"
 
 #include "kaddressbook_debug.h"
@@ -40,7 +42,7 @@ bool PrintStyle::setPreview(const QString &fileName)
 {
     QPixmap preview;
 
-    const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kaddressbook/printing/") + fileName);
+    const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kaddressbook/printing/"_L1 + fileName);
     if (path.isEmpty()) {
         qCDebug(KADDRESSBOOK_LOG) << "cannot locate preview image " << fileName << " in appdata";
         return false;
